summaryrefslogtreecommitdiff
path: root/bin
diff options
context:
space:
mode:
authorOssama Othman <ossama-othman@users.noreply.github.com>2002-01-30 00:03:30 +0000
committerOssama Othman <ossama-othman@users.noreply.github.com>2002-01-30 00:03:30 +0000
commit7ed00d83c4af63a449482e83a081b8ee286c4be1 (patch)
tree912a3d8ab1d382ea5bae01c998298a69c8b43a9e /bin
parentcdf77e573c2fb17704e80d7bce7117ee4da846d8 (diff)
downloadATCD-7ed00d83c4af63a449482e83a081b8ee286c4be1.tar.gz
ChangeLogTag:Tue Jan 29 16:01:54 2002 Ossama Othman <ossama@uci.edu>
Diffstat (limited to 'bin')
-rwxr-xr-xbin/fuzz.pl8
1 files changed, 4 insertions, 4 deletions
diff --git a/bin/fuzz.pl b/bin/fuzz.pl
index a3d6b1371b8..f32e647d42b 100755
--- a/bin/fuzz.pl
+++ b/bin/fuzz.pl
@@ -20,7 +20,7 @@ use Getopt::Std;
# - Guards in .h files
# - no global functions
# - other commit_check checks, tabs, trailing spaces.
# - _narrow() should always have TAO_ENV_ARG_PARAMETER
# - Using ACE_TRY_NEW_ENV (Nanbor suggests using ACE_DECLARE_NEW_CORBA_ENV)
#
# And others in ACE_Guidelines and Design Rules
@@ -631,7 +631,7 @@ sub check_for_bad_ace_trace()
# This test checks missing TAO_ENV_ARG_PARAMETER when using
# resolve_initial_references
sub check_for_missing_rir_env ()
{
@@ -666,14 +666,14 @@ sub check_for_missing_rir_env ()
$in_rir = 1;
}
- if (m/TAO_ENV_ARG_PARAMETER/) {
+ if (m/ACE_ENV_ARG_PARAMETER/) {
$found_env = 1;
}
if ($in_rir == 1 && m/\;\s*$/) {
$in_rir = 0;
if ($found_env != 1) {
- print_error ("Missing TAO_ENV_ARG_PARAMETER in"
+ print_error ("Missing ACE_ENV_ARG_PARAMETER in"
. " resolve_initial_references"
. " in $file ($line)");
}
@@ -20,7 +20,7 @@ use Getopt::Std;
# - no global functions
# - other commit_check checks, tabs, trailing spaces.
-# - _narrow() should always have TAO_ENV_ARG_PARAMETER
+# - _narrow() should always have ACE_ENV_ARG_PARAMETER
# - Using ACE_TRY_NEW_ENV (Nanbor suggests using ACE_DECLARE_NEW_CORBA_ENV)
#
@@ -631,7 +631,7 @@ sub check_for_bad_ace_trace()
# And others in ACE_Guidelines and Design Rules
-# This test checks missing TAO_ENV_ARG_PARAMETER when using
+# This test checks missing ACE_ENV_ARG_PARAMETER when using
# resolve_initial_references
sub check_for_missing_rir_env ()